%define major	9
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Name:		draco
Version:	1.5.7
Release:	%mkrel 1
Summary:	Compress and decompres 3D geometric meshes and point clouds
License:	Apache-2.0
Group:		System/Libraries
URL:		https://google.github.io/draco
Source0:	https://github.com/google/draco/archive/%{version}/%{name}-%{version}.tar.gz
# Downstream-only patch that unconditionally links a system copy of gtest,
# rather than expecting a git submodule as upstream prefers (and gtest upstream
# would recommend).
Patch0:		0001-Use-system-gtest.patch
# https://github.com/google/draco/pull/1001
Patch1:		0002-build-shared-lib.patch
## debian patches
Patch11:	0001-Fix-removal-of-build-dir-prefix-from-include-path.patch
Patch12:	0002-Install-proper-CMake-targets.patch
Patch13:	0003-Use-C-17-filesystem-library.patch
Patch14:	0004-Set-DRACO_LIBRARIES-for-backwards-compatibility.patch
Patch15:	0005-Fix-FTBFS-with-GCC-13.patch
Patch16:	0006-Fix-tinygltf-FsCallbacks.patch
BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	help2man
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(nlohmann_json)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tinygltf)

%description
A library for compressing and decompressing 3D geometric meshes and point
clouds.

%files
%license LICENSE
%{_bindir}/%{name}_decoder*
%{_bindir}/%{name}_encoder*
%{_bindir}/%{name}_transcoder*
%{_mandir}/man1/%{name}_decoder-%{version}.1*
%{_mandir}/man1/%{name}_encoder-%{version}.1*
%{_mandir}/man1/%{name}_transcoder-%{version}.1*

#---------------------------------------------------------------------------

%package -n %{libname}
Summary:	Compress and decompres 3D geometric meshes and point clouds
License:	Apache-2.0
Group:		System/Libraries

%description -n %{libname}
A library for compressing and decompressing 3D geometric meshes and point
clouds.

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}

#---------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for %{name}
License:	Apache-2.0
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for %{name}.

%files -n %{devname}
%license LICENSE
%doc AUTHORS README.md
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

#---------------------------------------------------------------------------

%prep
%autosetup -p1

# Remove precompiled CSS and Javascript along binaries
rm -fr {javascript,maya,docs/assets}

%build
%cmake \
    -DDRACO_TESTS:BOOL=OFF \
    -DDRACO_TRANSCODER_SUPPORTED=ON \
    -DDRACO_EIGEN_PATH=%{_includedir}/Eigen \
    -DDRACO_FILESYSTEM_PATH=%{_includedir} \
    -DDRACO_TINYGLTF_PATH=%{_includedir}/stb
%cmake_build

%install
%cmake_install

# manpages
mkdir -p %{buildroot}%{_mandir}/man1
LD_LIBRARY_PATH=%{buildroot}%{_libdir} help2man -N --version-string=%{version} \
	-o %{buildroot}%{_mandir}/man1/%{name}_decoder-%{version}.1 \
	%{buildroot}%{_bindir}/%{name}_decoder
LD_LIBRARY_PATH=%{buildroot}%{_libdir} help2man -N --version-string=%{version} \
	-o %{buildroot}%{_mandir}/man1/%{name}_encoder-%{version}.1 \
	%{buildroot}%{_bindir}/%{name}_encoder
LD_LIBRARY_PATH=%{buildroot}%{_libdir} help2man -N --version-string=%{version} \
	-o %{buildroot}%{_mandir}/man1/%{name}_transcoder-%{version}.1 \
	%{buildroot}%{_bindir}/%{name}_transcoder


%changelog
* Mon Mar 04 2024 daviddavid <daviddavid> 1.5.7-1.mga10
+ Revision: 2047550
- new version: 1.5.7
- now libmajor is 9

* Fri Jan 19 2024 daviddavid <daviddavid> 1.5.6-3.mga10
+ Revision: 2032175
- enable transcoder tool

* Thu Jan 18 2024 daviddavid <daviddavid> 2.mga10-current
+ Revision: 2032025
- add some debian patches and especially one to set DRACO_LIBRARIES
  for backwards compatibility

* Mon Nov 06 2023 daviddavid <daviddavid> 1.5.6-1.mga10
+ Revision: 2004708
- initial package draco (needed for qgis 3.34 LTR)

